Learn R Programming

kableExtra (version 1.4.1)

linebreak: Make linebreak in LaTeX Table cells

Description

This function generates LaTeX code of makecell so that users can have linebreaks in their table

Usage

linebreak(x, align = "l", double_escape = F, linebreaker = "\n")

Arguments

x

A character vector

align

Alignment of the text

double_escape

Whether special character should be double escaped. Default is FALSE.

linebreaker

Symbol for linebreaks to replace. Default is \n.

Details

Not all align settings are supported, but simple ones such as l, c, r should be fine. More exotic ones like p{3cm} should work too, but may not if they are too complicated.