Add footnote to your favorite kable output. So far this function
only works when you define format in your kable function or in the
global knitr option knitr.table.format. In latex, we are using the
threeparttable package so you need to import this package in your
YAML header.