Learn R Programming

kableExtra (version 0.3.0)

group_rows: Put a few rows of a table into one category

Description

Group a few rows in a table together under a label.

Usage

group_rows(kable_input, group_label, start_row, end_row,
  label_row_css = "border-bottom: 1px solid;", latex_gap_space = "0.5em")

Arguments

kable_input

Output of knitr::kable() with format specified

group_label

A character string for the name of the group

start_row

A numeric value that tells the function in which row the group starts. Note that the counting excludes header rows and other group labeling rows

end_row

A numeric value that tells the function in which row the group ends.

label_row_css

A character string for any customized css used for the labeling row. By default, the labeling row will have a solid black line underneath. Only useful for HTML documents.

latex_gap_space

A character value telling LaTeX how large the gap between the previous row and the group labeling row. Only useful for LaTeX documents.

Examples

Run this code
# NOT RUN {
x <- knitr::kable(head(mtcars), "html")
# Put Row 2 to Row 5 into a Group and label it as "Group A"
group_rows(x, "Group A", 2, 5)

# }

Run the code above in your browser using DataLab