A numeric value that tells the function in which row the
group starts. Note that the counting excludes header rows and other group
labeling rows
end_row
A numeric value that tells the function in which row the group
ends.
label_row_css
A character string for any customized css used for the
labeling row. By default, the labeling row will have a solid black line
underneath. Only useful for HTML documents.
latex_gap_space
A character value telling LaTeX how large the gap
between the previous row and the group labeling row. Only useful for LaTeX
documents.