Learn R Programming

kableExtra (version 0.3.0)

row_spec: Specify the look of the selected row

Description

This function allows users to select a row and then specify its look. Right now it supports the following two properties: bold text and italic text.

Usage

row_spec(kable_input, row, bold = FALSE, italic = FALSE)

Arguments

kable_input

Output of knitr::kable() with format specified

row

A numeric value indicating which row to be selected. You don't need to count in header rows or group labeling rows.

bold

A T/F value to control whether the text of the selected row need to be bolded.

italic

A T/F value to control whether the text of the selected row need to be emphasized.

Examples

Run this code
# NOT RUN {
x <- knitr::kable(head(mtcars), "html")
row_spec(x, 1, bold = TRUE, italic = TRUE)

# }

Run the code above in your browser using DataLab