powered by
This function allows users to select a row and then specify its look. Right now it supports the following two properties: bold text and italic text.
row_spec(kable_input, row, bold = FALSE, italic = FALSE)
Output of knitr::kable() with format specified
knitr::kable()
format
A numeric value indicating which row to be selected. You don't need to count in header rows or group labeling rows.
A T/F value to control whether the text of the selected row need to be bolded.
A T/F value to control whether the text of the selected row need to be emphasized.
# NOT RUN { x <- knitr::kable(head(mtcars), "html") row_spec(x, 1, bold = TRUE, italic = TRUE) # }
Run the code above in your browser using DataLab